import { listImages } from "../../utils/s3.js";

export async function GET({ request, url }) {
  try {
    // Get query parameters
    const continuationToken = url.searchParams.get("continuationToken");
    const limit = Number.parseInt(url.searchParams.get("limit") || "20", 10);

    // Fetch images from S3
    const result = await listImages(continuationToken, limit);

    // Return the images and continuation token
    return new Response(JSON.stringify(result), {
      status: 200,
      headers: {
        "Content-Type": "application/json",
        "Cache-Control": "max-age=60, stale-while-revalidate=300",
      },
    });
  } catch (error) {
    console.error("Error fetching images:", error);
    return new Response(JSON.stringify({ error: "Failed to fetch images" }), {
      status: 500,
      headers: {
        "Content-Type": "application/json",
      },
    });
  }
}
